package com.smppw.analysis.infrastructure.config;

import lombok.Getter;
import lombok.Setter;
import org.springframework.boot.context.properties.ConfigurationProperties;
import org.springframework.context.annotation.Configuration;

import java.time.Duration;
import java.util.List;

/**
 * @author wangzaijun
 * @date 2023/8/4 17:35
 * @description 一些系统配置，包括所有的服务的可配置的数据
 */
@Configuration
@ConfigurationProperties(prefix = "smppw.data.analysis")
public class AnalysisProperty {
    /**
     * 远程调用的python接口地址
     */
    private String pyUrl = "http://localhost:8088/";
    /**
     * 缓存类型，支持memory、redis，默认memory
     */
    private String cacheType = "memory";
    /**
     * 参数是否签名验证
     */
    private Boolean enableSign = Boolean.TRUE;
    /**
     * 签名配置
     * appKey 不能随意更改，要和RankDao的实现类一致
     */
    private List<AppSign> appSigns;

    public String getPyUrl() {
        return pyUrl;
    }

    public void setPyUrl(String pyUrl) {
        this.pyUrl = pyUrl;
    }

    public String getCacheType() {
        return cacheType;
    }

    public void setCacheType(String cacheType) {
        this.cacheType = cacheType;
    }

    public Boolean getEnableSign() {
        return enableSign;
    }

    public void setEnableSign(Boolean enableSign) {
        this.enableSign = enableSign;
    }

    public List<AppSign> getAppSigns() {
        return appSigns;
    }

    public void setAppSigns(List<AppSign> appSigns) {
        this.appSigns = appSigns;
    }

    @Setter
    @Getter
    public static class AppSign {
        private Boolean enabled = Boolean.FALSE;
        private String appKey;
        private String appSecret;
        /**
         * 默认超时5分钟超时
         */
        private Duration timeout = Duration.ofMinutes(5);
    }
}
